utils.specutils_stis package
============================

get_association_indices
---------------------------------------------------

.. automodule:: utils.specutils_stis.get_association_indices
    :members:
    :undoc-members:
    :show-inheritance:

plotspec
------------------------------------

.. autofunction:: utils.specutils_stis.plotspec

readspec
------------------------------------

.. autofunction:: utils.specutils_stis.readspec

stis1dspectrum
------------------------------------------

.. automodule:: utils.specutils_stis.stis1dspectrum
    :members:
    :undoc-members:
    :show-inheritance:
